@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBKGAPI2_TYPES_H
@@ -115,6 +115,14 @@ class Revision;
 typedef QSharedPointer<Revision> RevisionPtr;
 typedef QList<RevisionPtr> RevisionsList;
 
+class Drives;
+typedef QSharedPointer<Drives> DrivesPtr;
+typedef QList<DrivesPtr> DrivesList;
+
+class Teamdrive;
+typedef QSharedPointer<Teamdrive> TeamdrivePtr;
+typedef QList<TeamdrivePtr> TeamdrivesList;
+
 class User;
 typedef QSharedPointer<User> UserPtr;
 typedef QList<UserPtr> UsersList;
